==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/Route53/GetTrafficPolicyInstanceCount.pm <==

package Paws::Route53::GetTrafficPolicyInstanceCount;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetTrafficPolicyInstanceCount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2013-04-01/trafficpolicyinstancecount');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Route53::GetTrafficPolicyInstanceCountResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
  
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53::GetTrafficPolicyInstanceCount - Arguments for method GetTrafficPolicyInstanceCount on Paws::Route53

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetTrafficPolicyInstanceCount on the 
Amazon Route 53 service. Use the attributes of this class
as arguments to method GetTrafficPolicyInstanceCount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetTrafficPolicyInstanceCount.

As an example:

  $service_obj->GetTrafficPolicyInstanceCount(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetTrafficPolicyInstanceCount in L<Paws::Route53>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/Route53/GetTrafficPolicyInstanceCount.pm <==

package Paws::Route53::GetTrafficPolicyInstanceCount;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetTrafficPolicyInstanceCount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2013-04-01/trafficpolicyinstancecount');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Route53::GetTrafficPolicyInstanceCountResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
  
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53::GetTrafficPolicyInstanceCount - Arguments for method GetTrafficPolicyInstanceCount on L<Paws::Route53>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetTrafficPolicyInstanceCount on the
L<Amazon Route 53|Paws::Route53> service. Use the attributes of this class
as arguments to method GetTrafficPolicyInstanceCount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetTrafficPolicyInstanceCount.

=head1 SYNOPSIS

    my $route53 = Paws->service('Route53');
    my $GetTrafficPolicyInstanceCountResponse =
      $route53->GetTrafficPolicyInstanceCount();

    # Results:
    my $TrafficPolicyInstanceCount =
      $GetTrafficPolicyInstanceCountResponse->TrafficPolicyInstanceCount;

    # Returns a L<Paws::Route53::GetTrafficPolicyInstanceCountResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/route53/GetTrafficPolicyInstanceCount>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetTrafficPolicyInstanceCount in L<Paws::Route53>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
